pub fn lower_sil_to_bytecode(
artifact: &SilArtifact,
) -> Result<BytecodeModule, String>Expand description
Lower a SIL artifact to bytecode. Handles multiple functions by grouping instructions under sil @ headers.
pub fn lower_sil_to_bytecode(
artifact: &SilArtifact,
) -> Result<BytecodeModule, String>Lower a SIL artifact to bytecode. Handles multiple functions by grouping instructions under sil @ headers.